@@ -21,7 +21,7 @@ use Pinto::Types qw(Uri Dir);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.058'; # VERSION
+our $VERSION = '0.059'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -189,7 +189,7 @@ sub registration_ok {
     $self->tb->is_eq($pkg->version, $pkg_ver,  "Package has correct version");
 
     # Test distribution object...
-    my $dist = $pkg->distribution;
+    my $dist = $reg->distribution;
     $self->tb->is_eq($dist->path,  $dist_path, "Distribution has correct dist path");
 
     # Archive should be reachable through stack symlink (e.g. $stack/authors/id/A/AU/AUTHOR/Foo-1.0.tar.gz)
@@ -407,7 +407,7 @@ Pinto::Tester - A class for testing a Pinto repository
 
 =head1 VERSION
 
-version 0.058
+version 0.059
 
 =head1 AUTHOR
 
